@@ -1,5 +1,5 @@
 package Adapter::Async::OrderedList;
-$Adapter::Async::OrderedList::VERSION = '0.004';
+$Adapter::Async::OrderedList::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Adapter::Async::OrderedList - API for dealing with ordered lists
 
 =head1 VERSION
 
-Version 0.004
+Version 0.005
 
 =head1 DESCRIPTION
 
@@ -117,16 +117,40 @@ The adapter itself doesn't do much with this.
 
 =cut
 
+=head1 METHODS
+
+=head2 insert
+
+Inserts data before the given position.
+
+ $adapter->insert(3, [...])
+
+=cut
+
 sub insert {
 	my ($self, $idx, $data) = @_;
 	$self->splice($idx, 0, $data)
 }
 
+=head2 append
+
+Appends data after the given position.
+
+ $adapter->append(3, [...])
+
+=cut
+
 sub append {
 	my ($self, $idx, $data) = @_;
 	$self->splice($idx + 1, 0, $data)
 }
 
+=head2 push
+
+Appends data to the end of the list.
+
+=cut
+
 sub push {
 	my ($self, $data) = @_;
 	$self->count->then(sub {
@@ -134,11 +158,23 @@ sub push {
 	})
 }
 
+=head2 unshift
+
+Inserts data at the start of the list.
+
+=cut
+
 sub unshift {
 	my ($self, $data) = @_;
 	$self->splice(0, 0, $data)
 }
 
+=head2 pop
+
+Removes the last element from the list, will resolve with the value.
+
+=cut
+
 sub pop {
 	my ($self, $data) = @_;
 	$self->count->then(sub {
@@ -146,6 +182,12 @@ sub pop {
 	})
 }
 
+=head2 shift
+
+Removes the first element from the list, will resolve with the value.
+
+=cut
+
 sub shift {
 	my ($self, $data) = @_;
 	$self->splice(0, 1)
